@@ -1,7 +1,7 @@
 vcov.mcmc.list.dc <-
-function(object, invfisher=TRUE, ...)
+function(object, invfisher = TRUE, ...)
 {
-    rval <- cov(mcmcapply(object, array))
+    rval <- cov(as.matrix(object), ...)
     if (invfisher)
         rval <- rval * nclones(object)
     rval
